Statistics
==========

The **Statistics** module consists of a set of 19 functions that are commonly 
used in the forecast verification process. These can be classified in 3 groups 
in function of their purpose:

  - [**Normalizing and filtering the signal**](#normalizing): `Clim()`, 
`Ano()`, `Ano_Crossvalid()`, `Trend()`, `Consist_Trend()`, `Regression()`, 
`Smoothing()`, `Spectrum()` and `Filter()`.
  - [**Descripting the signal**](#descripting): `Alpha()`, `FitAcfCoef()` and 
`FitAutocor()`.
  - [**Generating derivate signals**](#generating_der): `Season()`, 
`ProbBins()` and `StatSeasAtlHurr()`.
  - [**Generating new signals**](#generating_new): `GenSeries()`, 
`Toymodel()`, `Eno()` and `EnoNew()`.

Normalization and filtering the signal<a name="normalizing"></a>
--------------------------------------

### Climatologies and bias correction
Clim

### Anomalies
Ano, Ano_Crossvalid

### Detrending data
Trend, Consist_Trend, Regression

### Frequency filtering
Smoothing, Spectrum, Filter

Descripting the signal<a name="descripting"></a>
----------------------

### Linear trend


### Frequency spectrum


### Autocorrelation
Knowing whether a signal is time-correlated with itself is a crucial step to 
determine whether the size of the sample is large enough to yield a robust 
validation. It is also useful to build synthetic models with the same time 
correlation behaviour as another.  
The function `Alpha()` serves to compute the best estimate of the 
autocorrelation of a signal at 1 time-step lag. Knowing the best estimate 
is needed to __________.  

`Alpha()` has two parameters to enable linear detrending and/or filtering of 
frequency peaks, convenient if ___________.

Assuming we have followed the same data retrieval process as in the 
[**Example**](example.md), we can calculate the best estimate of 
autocorrelation at lag 1 of the bias-corrected, detrended, observed anomalies 
as follows:
```r
clim <- Clim(data$mod, data$exp)
ano <- Ano(clim$clim_exp, clim$clim_obs)
autocorr <- Alpha(ano$obs[1, 1, , 1], detrend = TRUE)
```
Internally, `Alpha()` calls `FitAcfCoef()`. `FitAcfCoef()` computes the 
autocorrelation from the first estimates of the autocorrelation at lags 1 and 
2, that can be obtained providing the original time series to the R built-in 
function `acf()`:
```r
estacf <- acf(ano$obs[1, 1, , 1], plot = FALSE)$acf
autocorr <- FitAcfCoef(max(estacf[2], 0), max(estacf[3], 0))
```  
`FitAutocor()` estimates the autocorrelation from the first autocorrelation 
estimate and a window where to seek in with a dichotomial method.
```r
estacf <- acf(ano$obs[1, 1, , 1], plot = FALSE)$acf
alpha <-  FitAutocor(estacf, c(-1, 1), 0.01)
```

Generating derivate signals<a name="generating_der"></a>
---------------------------

Seasonal means
Season
Should this go to data retrieval?

Cathegorizing data
ProbBins

Statistical downscaling
StatSeasAtlHurr

Generating new signals<a name="generating_new"></a>
----------------------

Empirical models
GenSeries, Toymodel, Eno, EnoNew

